==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Atención</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La grabación no empieza por insuficiencia de espacio en disco</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>No queda espacio libre en disco</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco
 </translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Paró la grabación, no queda espacio en disco</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró ningún gestor de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instale un gestor de archivos.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>La sesión de escritorio es Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>En este momento no se admite Wayland. Las grabaciones no mostrarán más que una pantalla negra. Finalice la sesión y acceda a una sesión de X11.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Sesión de escritorio Wayland detectada</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Cuadro de diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Voltear horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Voltear verticalmente</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar marco de ventana</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160 × 120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320 × 240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configuración de cámara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640 × 480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restablecer</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño de vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio en disco disponible:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Dejar de grabar tras</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco
 </translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segunda espera antes de grabar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar informe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl + Mayús + F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl + Mayús + F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl + Mayús + F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir última grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl + Mayús + F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar al empezar grabación</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Empezar aplicación minimizada</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Voltear horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Voltear verticalmente</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar marco de ventana</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restablecer todas las preferencias en el próximo inicio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia desde imágenes</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Grabación de pantalla</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia desde imágenes</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Fotograma anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Fotograma siguiente</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover el menú</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Cambiar a ventana</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró ningún gestor de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instale un gestor de archivos.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Atención</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La grabación no empieza por insuficiencia de espacio en disco</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>No queda espacio libre en disco</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco
 </translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Paró la grabación, no queda espacio en disco</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No se encontró ningún gestor de archivos.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instale un gestor de archivos.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Código fuente</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Sitio web</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traducciones</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccione uno o más dispositivos</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Cuadro de diálogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Voltear horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Voltear verticalmente</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar marco de ventana</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160 × 120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320 × 240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Configuración de cámara</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640 × 480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Área</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restablecer</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliación</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta regresiva</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Tamaño de vídeo:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Espacio en disco disponible:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tiempo de grabación:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Códec de vídeo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Códec de audio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No grabar el puntero del ratón</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hora</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Iniciar temporizador</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Dejar de grabar tras</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horas</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutos</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Segundos</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta del vídeo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Límite de espacio libre en disco
 </translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostrar en bandeja del sistema</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Segunda espera antes de grabar</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Buscar actualizaciones</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>No disponible</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invertir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Enviar informe</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl + Mayús + F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl + Mayús + F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl + Mayús + F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproducir última grabación</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl + Mayús + F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizar al empezar grabación</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Empezar aplicación minimizada</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Voltear horizontalmente</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Voltear verticalmente</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Blanco y negro</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Quitar marco de ventana</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restablecer todas las preferencias en el próximo inicio</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia desde imágenes</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Grabación de pantalla</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Registro</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Derechos de autor y licencia desde imágenes</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Fotograma anterior</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Fotograma siguiente</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Mover el menú</translation>
    </message>
</context>
</TS>
